@@ -17,7 +17,7 @@ SOAPpy.Config.debug=1
 # this could probably use a bit of help when run in the console instead of daemonized
 # by the way, this script seems not to be detaching from the controlling pty or daemonizing itself properly.  it's WRONG.
 # and it shouldn't even run as root!
-logging.basicConfig(filename="/var/log/dtc-xen.log",level=logging.DEBUG)
+logging.basicConfig(filename="/var/log/dtc-xen.log",level=logging.INFO)
 logging.info("Starting DTC SOAP server...")
 
 # A generalized decorator for logging exceptions
@@ -128,6 +128,16 @@ def destroyVPS(vpsname):
 	else:
 		return "NOTOK"
 
+def killVPS(vpsname,imagetype='lvm'):
+	username = getUser()
+	if username == dtcxen_user or username == vpsname:
+		logging.info("Destroying vps xen%s VPS partitions", vpsname)
+		cmd = "/usr/sbin/dtc_kill_vps_disk %s %s" % (vpsname, imagetype)
+		output = commands.getstatusoutput(cmd)
+		logging.debug("Command stdout: %s",cmd)
+	else:
+		return "NOTOK"
+
 def shutdownVPS(vpsname):
 	username = getUser()
 	if username == dtcxen_user or username == vpsname:
@@ -215,6 +225,12 @@ def changeVPSsshKey(vpsname,keystring):
 			file.write(keystring)
 			file.close()
 			os.chown(filename, getuserid(vpsname), getusergroup(vpsname))
+			# In case we are using authorized_keys2, we do it a 2nd time.
+			filename = "/var/lib/dtc-xen/ttyssh_home/%s/.ssh/authorized_keys2" % vpsname
+			file = open(filename, "w")
+			file.write(keystring)
+			file.close()
+			os.chown(filename, getuserid(vpsname), getusergroup(vpsname))
 		except IOError:
 			return "NOTOK - There was an error writing to", filename
 		return "OK"
@@ -560,9 +576,6 @@ def _authorize(*args, **kw):
 		# decode and analyze the string for the username and password
 		# (we slice the string from 6 onwards to remove the "Basic ")
 		username, password = base64.decodestring(ah[6:].strip()).split(":")
-		logging.debug( "Authorization string: \"%s\"" , ah )
-		# FIXME the pw should never end up the log
-		logging.debug( "Username: \"%s\" Password: \"%s\"" , username, password )
 
 		logging.debug("Loading /etc/dtc-xen/htpasswd...")
 		fd = open('/etc/dtc-xen/htpasswd', 'r') 
@@ -570,10 +583,7 @@ def _authorize(*args, **kw):
 		for line in fd:
 			u, h = line.strip().split(':')
 			if u == username:
-				logging.debug( "Found user: %s",username)
-				logging.debug( "Password from file: %s", h)
 				verify_pass = crypt.crypt(password, h[:2])
-				logging.debug( "Check hash password: %s",verify_pass)
 				if verify_pass == h:
 					fd.close()
 					logging.debug( "Password matches the one in the file!")
@@ -614,6 +624,7 @@ soapserver.registerFunction(testVPSServer)
 soapserver.registerFunction(startVPS)
 soapserver.registerFunction(destroyVPS)
 soapserver.registerFunction(shutdownVPS)
+soapserver.registerFunction(killVPS)
 soapserver.registerFunction(listStartedVPS)
 soapserver.registerFunction(getVPSState)
 soapserver.registerFunction(changeVPSxmPassword)
